diff --git a/history/history.go b/history/history.go
index f3d117d..d02e156 100644
--- a/history/history.go
+++ b/history/history.go
@@ -10,7 +10,6 @@ import (
"strings"
"time"
- "github.com/bouncepaw/mycorrhiza/user"
"github.com/bouncepaw/mycorrhiza/util"
)
@@ -77,8 +76,8 @@ func (rev Revision) TimeString() string {
return rev.Time.Format(time.RFC822)
}
-// HyphaeLinks returns a comma-separated list of hyphae that were affected by this revision as HTML string.
-func (rev Revision) HyphaeLinks() (html string) {
+// HyphaeLinksHTML returns a comma-separated list of hyphae that were affected by this revision as HTML string.
+func (rev Revision) HyphaeLinksHTML() (html string) {
hyphae := rev.hyphaeAffected()
for i, hyphaName := range hyphae {
if i > 0 {
@@ -92,7 +91,7 @@ func (rev Revision) HyphaeLinks() (html string) {
func (rev *Revision) descriptionForFeed() (html string) {
return fmt.Sprintf(
`
%s
-
Hyphae affected: %s
`, rev.Message, rev.HyphaeLinks())
+
Hyphae affected: %s
`, rev.Message, rev.HyphaeLinksHTML())
}
// Try and guess what link is the most important by looking at the message.
@@ -111,23 +110,6 @@ func (rev *Revision) bestLink() string {
}
}
-func (rev Revision) RecentChangesEntry() (html string) {
- if user.AuthUsed && rev.Username != "anon" {
- return fmt.Sprintf(`
-
-